@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2016-06-30'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -13,11 +13,14 @@ has exclude_module => (is=>'rw');
 has bench => (is=>'rw', default=>sub{1});
 has bench_startup => (is=>'rw', default=>sub{1});
 has sample_bench => (is=>'rw');
+has gen_html_tables => (is=>'rw', default=>sub{0});
+has result_split_fields => (is=>'rw');
 
 sub mvp_multivalue_args { qw(sample_bench include_module exclude_module) }
 
 use Bencher::Backend;
 use Data::Dmp;
+use Perinci::Result::Format::Lite;
 use Perinci::Sub::Normalize qw(normalize_function_metadata);
 use Perinci::Sub::ConvertArgs::Argv qw(convert_args_to_argv);
 use String::ShellQuote;
@@ -41,6 +44,32 @@ sub _md2pod {
     $pod . "\n\n\n";
 }
 
+sub _html_result {
+    my ($bench_res, $num) = @_;
+    $bench_res = Bencher::Backend::format_result(
+        $bench_res, undef, {render_as_text_table=>0},
+    );
+    $bench_res->[3]{'table.html_class'} = 'sortable-theme-bootstrap';
+    my $fres = Perinci::Result::Format::Lite::format($bench_res, "html");
+    $fres =~ s/(<table)/$1 data-sortable/
+        or die "Can't insert 'data-sortable' to table element";
+    my @res;
+
+    push @res, "=begin HTML\n\n";
+    if ($num == 1) {
+        push @res, join(
+            "",
+            '<script src="https://code.jquery.com/jquery-3.0.0.min.js"></script>', "\n",
+            '<script src="https://cdnjs.cloudflare.com/ajax/libs/sortable/0.8.0/js/sortable.min.js"></script>', "\n",
+            '<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/sortable/0.8.0/css/sortable-theme-bootstrap.min.css" />', "\n",
+        );
+    }
+    push @res, "\n$fres\n";
+    push @res, q|<script>$(document).ready(function () { $("pre:contains('#table|.$num.q|#')").remove() })</script>|, "\n";
+    push @res, "\n=end HTML\n\n";
+    join('', @res);
+}
+
 sub _process_module {
     no strict 'refs';
 
@@ -114,6 +143,7 @@ sub _process_module {
 
     # add Sample Benchmark Results section
     my @bench_res;
+    my $table_num = 1;
     {
         my $fres;
         my @pod;
@@ -159,8 +189,6 @@ sub _process_module {
                 note => 'Run by '.__PACKAGE__,
                 %{ $bench->{args} },
             );
-            $fres = Bencher::Backend::format_result($bench_res);
-            $fres =~ s/^/ /gm;
 
             if ($i == 0) {
                 my $num_cores = $bench_res->[3]{'func.cpu_info'}[0]{number_of_cores};
@@ -172,8 +200,28 @@ sub _process_module {
                     ".\n\n";
             }
 
-            push @pod, "$bench->{title}:\n\n$fres\n\n";
-            push @bench_res, $bench_res;
+            if ($self->result_split_fields) {
+                my $split_bench_res = Bencher::Backend::split_result(
+                    $bench_res, [split /\s*[,;]\s*|\s+/, $self->result_split_fields]);
+                for my $k (0..$#{$split_bench_res}) {
+                    my $split_item = $split_bench_res->[$k];
+                    if ($k == 0) { push @pod, "$bench->{title}:\n\n" }
+                    my $fres = Bencher::Backend::format_result($split_item->[1]);
+                    $fres =~ s/^/ /gm;
+                    push @pod, " #table$table_num#\n", " ", dmp($split_item->[0]), "\n$fres\n";
+                    $table_num++;
+                    push @pod, _html_result($bench_res, $table_num) if $self->gen_html_tables;
+                    push @bench_res, $split_item->[1];
+                }
+                push @pod, "\n";
+            } else {
+                my $fres = Bencher::Backend::format_result($bench_res);
+                $fres =~ s/^/ /gm;
+                push @pod, "$bench->{title}:\n\n #table$table_num#\n$fres\n\n";
+                push @pod, _html_result($bench_res, $table_num) if $self->gen_html_tables;
+                $table_num++;
+                push @bench_res, $bench_res;
+            }
         } # for sample_benches
 
         if ($self->bench_startup && @modules && !$scenario->{module_startup}) {
@@ -186,7 +234,9 @@ sub _process_module {
             );
             $fres = Bencher::Backend::format_result($bench_res2);
             $fres =~ s/^/ /gm;
-            push @pod, "Benchmark module startup overhead (C<< bencher -m $scenario_name --module-startup >>):\n\n", $fres, "\n\n";
+            push @pod, "Benchmark module startup overhead (C<< bencher -m $scenario_name --module-startup >>):\n\n #table$table_num#\n", $fres, "\n\n";
+            push @pod, _html_result($bench_res2, $table_num) if $self->gen_html_tables;
+            $table_num++;
         }
 
         $self->add_text_to_section(
@@ -344,7 +394,7 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.16 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-04-01.
+This document describes version 0.17 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-06-30.
 
 =head1 SYNOPSIS
 
@@ -377,7 +427,7 @@ run and shown.
 
 =for Pod::Coverage .*
 
-=head1 OPTIONS
+=head1 CONFIGURATION
 
 =head2 include_module+ => str
 
@@ -402,6 +452,21 @@ startup benchmark).
 
 Set to 0 if you do not want to produce module startup sample benchmark.
 
+=head2 gen_html_tables => bool (default: 0)
+
+=head2 result_split_fields => str
+
+If specified, will split result table into multiple tables using the specified
+fields (comma-separated). For example:
+
+ result_split_fields = dataset
+
+or:
+
+ result_split_fields = participant
+
+Note that module startup benchmark result is not split.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Plugin-Bencher-Scenario>.
